==> haskell-tasty-golden-2.3.2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-9Mqv6txY97a5c4JTEXFyeM
key: tasty-golden-2.3.2-9Mqv6txY97a5c4JTEXFyeM
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: f66319b7d5dc3cd3b15e784fc310c583
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-9Mqv6txY97a5c4JTEXFyeM
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.14.3.0-5bG7EuEt1Mz7nX3Ec5izyO
    process-1.6.5.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-4Ay6SdyclcILjSKEcT67wh
    temporary-1.3-56LtFOQQQhUGln6189Hptm
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.2-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-6RFxGJU869PHMuGHIOpZRZ
key: tasty-golden-2.3.2-6RFxGJU869PHMuGHIOpZRZ
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: ef9021fd272254956977f003cb8c4d24
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-6RFxGJU869PHMuGHIOpZRZ
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.14.3.0-2TcXyk5noJJ9JcSai3IjVr
    process-1.6.5.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-M30VzWQuNHEOMJRcZoLdD
    temporary-1.3-86OIviHidbW4076q5ChbcH
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
